@@ -12,4 +12,4 @@ from mrftools.clustering import *
 from mrftools.registration import *
 from mrftools.coilCombination import *
 from mrftools.ismrmrdQuaternionHelper import *
-from mrfrools.reconstruction import *
+from mrftools.reconstruction import *
