@@ -194,7 +194,7 @@ def PerformWalshCoilCombination(images, verbose=False, kernelSize=5, niter=5, de
     t = time.time()
     shape = np.shape(images)
     combinedImageData = torch.zeros((shape[0], shape[2], shape[3], shape[4]), dtype=torch.complex64)
-    coil_map, rho = coilCombination.calculate_csm_walsh(images[0,:,:,:,:], smoothing=kernelSize, niter=niter) 
+    coil_map, rho = coilCombination.calculateCoilmapsWalsh(images[0,:,:,:,:], smoothing=kernelSize, niter=niter) 
     for svdComponent in np.arange(0,shape[0]):
         im = (images[svdComponent, :, :, :, :]).to(device)
         combinedImageData[svdComponent, :, :, :] = torch.sum((im * torch.conj(coil_map)), axis=0)
@@ -213,7 +213,7 @@ def PerformInatiCoilCombination(images, verbose=False, kernelSize=5, niter=5, de
     t = time.time()
     shape = np.shape(images)
     combinedImageData = torch.zeros((shape[0], shape[2], shape[3], shape[4]), dtype=torch.complex64)
-    coil_map, combinedImageData[0, :, :, :] = coilCombination.calculate_csm_inati_iter_local(images[0,:,:,:,:], verbose=verbose, smoothing=kernelSize, niter=niter) 
+    coil_map, combinedImageData[0, :, :, :] = coilCombination.calculateCoilmapsInati(images[0,:,:,:,:], verbose=verbose, smoothing=kernelSize, niter=niter) 
     for svdComponent in np.arange(1,shape[0]):
         im = (images[svdComponent, :, :, :, :]).to(device)
         combinedImageData[svdComponent, :, :, :] = torch.sum((im * torch.conj(coil_map)), axis=0)
